@@ -34,6 +34,16 @@ from .utils import stripIEConditionals, addStartTag
 
 __all__ = ('AdvancedHTMLParser', 'IndexedAdvancedHTMLParser')
 
+def isInvisibleRootTag(tag):
+    '''
+        isInvisibleRootTag - Check if #tag is a the special root tag when there are multiple root elements.
+
+        @param tag <AdvancedTag> - A tag
+
+        @return <bool> - True if tag is the "fake" root tag used when multiple elements are at root level, otherwise False.
+    '''
+    return bool(tag.tagName == INVISIBLE_ROOT_TAG)
+
 class AdvancedHTMLParser(HTMLParser):
     '''
         AdvancedHTMLParser - This class parses and allows searching of  documents
@@ -382,6 +392,41 @@ class AdvancedHTMLParser(HTMLParser):
             elements += self.getElementsCustomFilter(filterFunc, child)
         return TagCollection(elements)
 
+
+    def getFirstElementCustomFilter(self, filterFunc, root='root'):
+        '''
+            getFirstElementCustomFilter - Scan elements using a provided function, stop and return the first match.
+
+                @see getElementsCustomFilter to match multiple elements
+
+            @param filterFunc <function>(node) - A function that takes an AdvancedTag as an argument, and returns True if some arbitrary criteria is met
+
+            @return - An AdvancedTag of the node that matched, or None if no match.
+        '''
+        (root, isFromRoot) = self._handleRootArg(root)
+
+        elements = []
+
+        if isFromRoot is True and filterFunc(root) is True:
+            return root
+
+        for child in root.children:
+            if filterFunc(child) is True:
+                return child
+            subRet = self.getFirstElementCustomFilter(filterFunc, child)
+            if subRet:
+                return subRet
+
+        return None
+
+    @property
+    def body(self):
+        return self.getFirstElementCustomFilter(lambda em : em.tagName == 'body')
+
+    @property
+    def head(self):
+        return self.getFirstElementCustomFilter(lambda em : em.tagName == 'head')
+
     def contains(self, em):
         '''
             Checks if #em is found anywhere within this element tree
@@ -731,6 +776,112 @@ class AdvancedHTMLParser(HTMLParser):
             self.feed(html)
 
 
+    def createElement(self, tagName):
+        '''
+            createElement - Create an unattached tag with the given tag name
+
+            @param tagName <str> - Name of tag
+
+            @return <AdvancedTag> - A tag with the given tag name
+        '''
+        return AdvancedTag(tagName=tagName.lower())
+
+
+    @classmethod
+    def createElementFromHTML(cls, html, encoding='utf-8'):
+        '''
+            createElementFromHTML - Creates an element from a string of HTML.
+
+                If this could create multiple root-level elements (children are okay),
+                  you must use #createElementsFromHTML which returns a list of elements created.
+
+            @param html <str> - Some html data
+
+            @param encoding <str> - Encoding to use for document
+
+            @raises MultipleRootNodeException - If given html would produce multiple root-level elements (use #createElementsFromHTML instead)
+
+            @return AdvancedTag - A single AdvancedTag
+
+            NOTE: If there is text outside the tag, they will be lost in this.
+              Use createBlocksFromHTML instead if you need to retain both text and tags.
+
+              Also, if you are just appending to an existing tag, use AdvancedTag.appendInnerHTML
+        '''
+        
+        parser = cls(encoding=encoding)
+
+        html = stripIEConditionals(html)
+        try:
+            HTMLParser.feed(parser, html)
+        except MultipleRootNodeException:
+            raise MultipleRootNodeException('Multiple nodes passed to createElementFromHTML method. Use #createElementsFromHTML instead to get a list of AdvancedTag elements.')
+
+        rootNode = parser.getRoot()
+        rootNode.remove()
+
+        return rootNode
+
+
+    @classmethod
+    def createElementsFromHTML(cls, html, encoding='utf-8'):
+        '''
+            createElementsFromHTML - Creates elements from provided html, and returns a list of the root-level elements
+                children of these root-level nodes are accessable via the usual means.
+
+            @param html <str> - Some html data
+
+            @param encoding <str> - Encoding to use for document
+
+            @return list<AdvancedTag> - The root (top-level) tags from parsed html.
+
+            NOTE: If there is text outside the tags, they will be lost in this.
+              Use createBlocksFromHTML instead if you need to retain both text and tags.
+
+              Also, if you are just appending to an existing tag, use AdvancedTag.appendInnerHTML
+        '''
+        # TODO: If text is present outside a tag, it will be lost.
+
+        parser = cls(encoding=encoding)
+
+        parser.parseStr(html)
+
+        rootNode = parser.getRoot()
+
+        rootNode.remove() # Detatch from temp document
+
+        if isInvisibleRootTag(rootNode):
+            return rootNode.children
+
+        return [rootNode]
+
+    @classmethod
+    def createBlocksFromHTML(cls, html, encoding='utf-8'):
+        '''
+            createBlocksFromHTML - Returns the root level node (unless multiple nodes), and 
+                a list of "blocks" added (text and nodes).
+
+            @return list< str/AdvancedTag > - List of blocks created. May be strings (text nodes) or AdvancedTag (tags)
+
+            NOTE:
+                Results may be checked by:
+
+                    issubclass(block.__class__, AdvancedTag)
+
+                If True, block is a tag, otherwise, it is a text node
+        '''
+        
+        parser = cls(encoding=encoding)
+
+        parser.parseStr(html)
+
+        rootNode = parser.getRoot()
+
+        rootNode.remove()
+
+        return rootNode.blocks
+
+
 class IndexedAdvancedHTMLParser(AdvancedHTMLParser):
     '''
         An AdvancedHTMLParser that indexes for much much faster searching. If you are doing searching/validation, this is your bet.
