@@ -7,14 +7,15 @@ from .Parser import AdvancedHTMLParser, IndexedAdvancedHTMLParser
 from .Tags import AdvancedTag, TagCollection, toggleAttributesDOM
 from .Formatter import AdvancedHTMLFormatter
 from .Validator import ValidatingAdvancedHTMLParser
-from .exceptions import InvalidCloseException, MissedCloseException, HTMLValidationException
+from .exceptions import InvalidCloseException, MissedCloseException, HTMLValidationException, MultipleRootNodeException
 from .SpecialAttributes import StyleAttribute
 
-__version__ = '7.0.2'
-__version_tuple__ = ('7', '0', '2')
-__int_version_tuple__ = (7, 0, 2)
+__version__ = '7.1.0'
+__version_tuple__ = ('7', '1', '0')
+__int_version_tuple__ = (7, 1, 0)
 
 __all__ = ( 'AdvancedHTMLParser', 'IndexedAdvancedHTMLParser', 'AdvancedHTMLFormatter', 'AdvancedTag', 'TagCollection',
-    'ValidatingAdvancedHTMLParser', 'MissedCloseException', 'InvalidCloseException', 'HTMLValidationException', 'StyleAttribute', 'toggleAttributesDOM' )
+    'ValidatingAdvancedHTMLParser', 'MissedCloseException', 'InvalidCloseException', 'HTMLValidationException', 'MultipleRootNodeException',
+    'StyleAttribute', 'toggleAttributesDOM' )
 
 #vim: set ts=4 sw=4 expandtab
