@@ -178,6 +178,52 @@ class TestGeneral(object):
 
         assert 'onclick="alert(&quot;hi&quot;);"' in tag.outerHTML , 'Expected to escape quotes in attribute. Got: %s' %(tag.outerHTML, )
 
+    def test_getBody(self):
+        parser = AdvancedHTMLParser.AdvancedHTMLParser()
+        parser.parseStr(self.testHTML)
+
+        bodyEm = parser.body
+
+        assert bodyEm , 'Expected ".body" property to fetch an element'
+        assert bodyEm.tagName == 'body' , 'Got wrong body element'
+
+        parser = AdvancedHTMLParser.AdvancedHTMLParser()
+        parser.parseStr('<div id="hello"> <span> One </span> </div>')
+        
+        bodyEm = parser.body
+        
+        assert not bodyEm , 'Expected to find no "body" when no <body> tag is present.'
+        
+        parser = AdvancedHTMLParser.AdvancedHTMLParser()
+        parser.parseStr('<div id="hello"> <span> One </span> </div> <div id="other">Cheese</div>')
+
+        bodyEm = parser.body
+
+        assert not bodyEm , 'Expected to find no "body" when no <body> tag is present.'
+
+
+    def test_getHead(self):
+        parser = AdvancedHTMLParser.AdvancedHTMLParser()
+        parser.parseStr(self.testHTML)
+
+        headEm = parser.head
+
+        assert headEm , 'Expected ".head" property to fetch an element'
+        assert headEm.tagName == 'head' , 'Got wrong head element'
+
+        parser = AdvancedHTMLParser.AdvancedHTMLParser()
+        parser.parseStr('<div id="hello"> <span> One </span> </div>')
+        
+        headEm = parser.head
+        
+        assert not headEm , 'Expected to find no "head" when no <head> tag is present.'
+        
+        parser = AdvancedHTMLParser.AdvancedHTMLParser()
+        parser.parseStr('<div id="hello"> <span> One </span> </div> <div id="other">Cheese</div>')
+
+        headEm = parser.head
+
+        assert not headEm , 'Expected to find no "head" when no <head> tag is present.'
 
 if __name__ == '__main__':
     subprocess.Popen('GoodTests.py "%s"' %(sys.argv[0],), shell=True).wait()
